==> hyades.source_3.0.1_20040922_0955.zip: org/eclipse/hyades/logging/events/cbe/util/EventMessages_fr.java <==
package org.eclipse.hyades.logging.events.cbe.util;

import java.util.ListResourceBundle;
import org.eclipse.hyades.logging.events.cbe.util.EventMessages;

/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

/**
 * French resource bundle.
 * 
 * @author Paul E. Slauenwhite
 * @version 1.0.1
 * @since 1.0.1
 */
public class EventMessages_fr extends ListResourceBundle {

    /**************************************************************************
    * Implements java.util.ListResourceBundle.getContents().
    * @see java.util.ListResourceBundle#getContents
    **************************************************************************/

    public Object[][] getContents() {
        return contents_;
    }

    /**************************************************************************
    * Resource table
    **************************************************************************/
    private final static Object[][] contents_ = { { EventMessages.LOG_INVALID_JNDI_REFERENCE_EXC_, "IWAT0187E La r\u00e9f\u00e9rence obtenue \u00e0 partir du nom JNDI sp\u00e9cifi\u00e9 n''est pas une r\u00e9f\u00e9rence \u00e0 une fabrique d''\u00e9v\u00e9nements.\nNom JNDI : {0}" }, {
        EventMessages.LOG_FAILED_TO_SERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0188E Le gestionnaire de contenu d''\u00e9v\u00e9nement ne peut pas \u00eatre converti en format binaire.\nInformations compl\u00e9mentaires, le cas \u00e9ch\u00e9ant : {0}" }, {
        EventMessages.LOG_FAILED_TO_DESERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0189E Le gestionnaire de contenu d''\u00e9v\u00e9nement r\u00e9f\u00e9renc\u00e9 par ce nom JNDI ne peut pas \u00eatre reconverti \u00e0 partir de son format binaire.\nNom JNDI : {0} \nInformations compl\u00e9mentaires, le cas \u00e9ch\u00e9ant : {1}" }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_EXC_, "IWAT0190E L''identificateur d''\u00e9v\u00e9nement figurant dans la propri\u00e9t\u00e9 Common Base Event sp\u00e9cifi\u00e9e doit commencer par un caract\u00e8re alphab\u00e9tique.\nPropri\u00e9t\u00e9 : {0} \nIdentificateur : {1} " }, {
        EventMessages.LOG_VALUE_ARRAY_SIZE_MISMATCH_EXC_, "IWAT0191E L''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues sp\u00e9cifi\u00e9 est un type qui requiert un seul \u00e9l\u00e9ment \u00e0 l''int\u00e9rieur de son tableau de valeurs, mais il en contient plusieurs.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {1}\nType : {2} \nNombre de valeurs : {0} " }, {
        EventMessages.LOG_INVALID_TYPE_CONVERSION_EXC_, "IWAT0192E La valeur dans l''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues ne peut pas \u00eatre convertie dans le type sp\u00e9cifi\u00e9.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {2} \nValeur : {0} \nType : {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_TYPE_EXC_, "IWAT0193E L''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues poss\u00e8de un type qui n''est pas valide.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {0}\nType : {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_VALUE_NULL_EXC_, "IWAT0194E L''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues contient une valeur ''null''. Si le type est un tableau, cela signifie qu''un ou plusieurs \u00e9l\u00e9ments sont ''null''.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {0} \nType : {1} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_BOOLEAN_EXC_, "IWAT0195E L''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues contient une cha\u00eene qui n''est pas une cha\u00eene bool\u00e9enne valide.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {0}\nType : {1} \nCha\u00eene : {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_DATE_EXC_, "IWAT0196E L''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues contient une cha\u00eene dateTime qui n''est pas valide.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {0}\nType : {1}\nCha\u00eene dateTime : {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_1_EXC_, "IWAT0197E L''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues doit contenir un nombre pair de caract\u00e8res dans la propri\u00e9t\u00e9 hexValue.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {0} \nType : {1} \nValeur : {2} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_2_EXC_, "IWAT0198E L''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues contient un caract\u00e8re non hexad\u00e9cimal dans la propri\u00e9t\u00e9 hexValue.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {0} \nType : {1} \nValeur : {2} \nCaract\u00e8re non hexad\u00e9cimal : {3} " }, {
        EventMessages.LOG_INVALID_SITUATION_TYPE_EXC_, "IWAT0199E La valeur de la propri\u00e9t\u00e9 sp\u00e9cifi\u00e9e n''est pas valide.\nPropri\u00e9t\u00e9 : {0} \nValeur : {1} \nValeurs admises : {2} " }, {
        EventMessages.LOG_INVALID_CREATION_TIME_EXC_, "IWAT0200E La valeur dateTime de la propri\u00e9t\u00e9 sp\u00e9cifi\u00e9e n''a pas pu \u00eatre interpr\u00e9t\u00e9e.\nPropri\u00e9t\u00e9 : {0} \nValeur : {1} " }, {
        EventMessages.LOG_INVALID_LIST_ELEMENT_LENGTH_EXC_, "IWAT0201E La longueur d''un \u00e9l\u00e9ment dans la propri\u00e9t\u00e9 sp\u00e9cifi\u00e9e d\u00e9passe le nombre maximum de caract\u00e8res.\nPropri\u00e9t\u00e9 : {1} \nEl\u00e9ment : {0} \nLongueur maximale : {2} " }, {
        EventMessages.LOG_VALUE_OUT_OF_RANGE_EXC_, "IWAT0202E La valeur d''une propri\u00e9t\u00e9 est en dehors de la plage valide.\nPropri\u00e9t\u00e9 : {1} \nValeur : {0} \nPlage valide : {2} \u00e0 {3} " }, {
        EventMessages.LOG_MISSING_REQUIRED_ATTRIBUTE_EXC_, "IWAT0203E Il manque une propri\u00e9t\u00e9 obligatoire dans un \u00e9v\u00e9nement Common Base Event.\nPropri\u00e9t\u00e9 : {0} " }, {
        EventMessages.LOG_MUTUALLY_EXCLUSIVE_ATTRIBUTES_EXC_, "IWAT0204E L''\u00e9v\u00e9nement Common Base Event contient des propri\u00e9t\u00e9s qui s''excluent mutuellement.\nPropri\u00e9t\u00e9 1 : {0} \nPropri\u00e9t\u00e9 2 : {1} " }, {
        EventMessages.LOG_INVALID_VERSION_EXC_, "IWAT0205E La version sp\u00e9cifi\u00e9e dans la propri\u00e9t\u00e9 {0} n''est pas valide. La valeur doit \u00eatre 1.0.1.\nValeur : {1} " }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_LENGTH_EXC_, "IWAT0206E La longueur de l''identificateur, dans la propri\u00e9t\u00e9 sp\u00e9cifi\u00e9e de l''\u00e9v\u00e9nement Common Base Event, est en dehors de la plage valide, qui est de 32 \u00e0 64 caract\u00e8res.\nPropri\u00e9t\u00e9 : {0} \nValeur : {1} " }, {
        EventMessages.LOG_INVALID_LENGTH_EXC_, "IWAT0207E La longueur de la valeur, dans la propri\u00e9t\u00e9 sp\u00e9cifi\u00e9e de l''\u00e9v\u00e9nement Common Base Event, d\u00e9passe le nombre maximum de caract\u00e8res.\nPropri\u00e9t\u00e9 : {0} \nValeur : {1} \nLongueur : {2} \nNombre maximal de caract\u00e8res : {3} " }, {
        EventMessages.LOG_INVALID_LENGTH_RANGE_EXC_, "IWAT0208E La longueur de la valeur, dans la propri\u00e9t\u00e9 sp\u00e9cifi\u00e9e de l''\u00e9v\u00e9nement Common Base Event, est en dehors de la plage valide.\nPropri\u00e9t\u00e9 : {0} \nValeur : {1} \nLongueur : {2} \nPlage de longueur valide : {3} " }, {
        EventMessages.LOG_MISSING_ATTRIBUTES_EXC_, "IWAT0209E Les propri\u00e9t\u00e9s sp\u00e9cifi\u00e9es doivent \u00eatre soit toutes pr\u00e9sentes, soit toutes absentes.\nPropri\u00e9t\u00e9s : {0} " }, {
        EventMessages.LOG_INCONSISTENT_ATTRIBUTES_EXC_, "IWAT0210E Lorsque la valeur de la propri\u00e9t\u00e9 {0} figurant dans l''\u00e9v\u00e9nement Common Base Event est \u00e9gale \u00e0 {1}, la liste sp\u00e9cifi\u00e9e de propri\u00e9t\u00e9s ne doit pas \u00eatre pr\u00e9sente.\nListe : {2} " }, {
        EventMessages.LOG_CATEGORY_MISMATCH_EXC_, "IWAT0211E La valeur de la propri\u00e9t\u00e9 {0} ne correspond pas \u00e0 la classe d''objet r\u00e9f\u00e9renc\u00e9e par la propri\u00e9t\u00e9 situationType.\nValeur : {1} \nClasse d''objet : {2}." }, {
        EventMessages.LOG_COMPONENT_IDENTIFICATION_INVALID_LOCATION_TYPE_EXC_, "IWAT0212E L''identification de composant contenant le composant nomm\u00e9 [{0}] comporte un type d''emplacement non valide : [{1}]" }, {
	    EventMessages.LOG_EVENT_SAX_PARSER_UNEXPECTED_XML_ELEMENT_EXC_, "Unexpected element ''{0}'' at line {1}, column {2}." }, {
	    EventMessages.LOG_EVENT_SAX_PARSER_INCORRECT_XML_ELEMENT_EXC_ , "Expected element ''{0}'' , but found element ''{1}'' at line {2}, column {3}."}
    };
}

==> hyades.source_3.0.2_20050225_1641.zip: org/eclipse/hyades/logging/events/cbe/util/EventMessages_fr.java <==
package org.eclipse.hyades.logging.events.cbe.util;

import java.util.ListResourceBundle;
import org.eclipse.hyades.logging.events.cbe.util.EventMessages;

/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

/**
 * French resource bundle.
 * 
 * @author Paul E. Slauenwhite
 * @version 1.0.1
 * @since 1.0.1
 */
public class EventMessages_fr extends ListResourceBundle {

    /**************************************************************************
    * Implements java.util.ListResourceBundle.getContents().
    * @see java.util.ListResourceBundle#getContents
    **************************************************************************/

    public Object[][] getContents() {
        return contents_;
    }

    /**************************************************************************
    * Resource table
    **************************************************************************/
    private final static Object[][] contents_ = { { EventMessages.LOG_INVALID_JNDI_REFERENCE_EXC_, "IWAT0187E La r\u00e9f\u00e9rence obtenue \u00e0 partir du nom JNDI sp\u00e9cifi\u00e9 n''est pas une r\u00e9f\u00e9rence \u00e0 une fabrique d''\u00e9v\u00e9nements.\nNom JNDI : {0}" }, {
        EventMessages.LOG_FAILED_TO_SERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0188E Le gestionnaire de contenu d''\u00e9v\u00e9nement ne peut pas \u00eatre converti en format binaire.\nInformations compl\u00e9mentaires, le cas \u00e9ch\u00e9ant : {0}" }, {
        EventMessages.LOG_FAILED_TO_DESERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0189E Le gestionnaire de contenu d''\u00e9v\u00e9nement r\u00e9f\u00e9renc\u00e9 par ce nom JNDI ne peut pas \u00eatre reconverti \u00e0 partir de son format binaire.\nNom JNDI : {0} \nInformations compl\u00e9mentaires, le cas \u00e9ch\u00e9ant : {1}" }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_EXC_, "IWAT0190E L''identificateur d''\u00e9v\u00e9nement figurant dans la propri\u00e9t\u00e9 Common Base Event sp\u00e9cifi\u00e9e doit commencer par un caract\u00e8re alphab\u00e9tique.\nPropri\u00e9t\u00e9 : {0} \nIdentificateur : {1} " }, {
        EventMessages.LOG_VALUE_ARRAY_SIZE_MISMATCH_EXC_, "IWAT0191E L''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues sp\u00e9cifi\u00e9 est un type qui requiert un seul \u00e9l\u00e9ment \u00e0 l''int\u00e9rieur de son tableau de valeurs, mais il en contient plusieurs.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {1}\nType : {2} \nNombre de valeurs : {0} " }, {
        EventMessages.LOG_INVALID_TYPE_CONVERSION_EXC_, "IWAT0192E La valeur dans l''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues ne peut pas \u00eatre convertie dans le type sp\u00e9cifi\u00e9.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {2} \nValeur : {0} \nType : {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_TYPE_EXC_, "IWAT0193E L''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues poss\u00e8de un type qui n''est pas valide.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {0}\nType : {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_VALUE_NULL_EXC_, "IWAT0194E L''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues contient une valeur ''null''. Si le type est un tableau, cela signifie qu''un ou plusieurs \u00e9l\u00e9ments sont ''null''.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {0} \nType : {1} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_BOOLEAN_EXC_, "IWAT0195E L''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues contient une cha\u00eene qui n''est pas une cha\u00eene bool\u00e9enne valide.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {0}\nType : {1} \nCha\u00eene : {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_DATE_EXC_, "IWAT0196E L''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues contient une cha\u00eene dateTime qui n''est pas valide.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {0}\nType : {1}\nCha\u00eene dateTime : {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_1_EXC_, "IWAT0197E L''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues doit contenir un nombre pair de caract\u00e8res dans la propri\u00e9t\u00e9 hexValue.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {0} \nType : {1} \nValeur : {2} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_2_EXC_, "IWAT0198E L''\u00e9l\u00e9ment de donn\u00e9es \u00e9tendues contient un caract\u00e8re non hexad\u00e9cimal dans la propri\u00e9t\u00e9 hexValue.\nEl\u00e9ment de donn\u00e9es \u00e9tendues : {0} \nType : {1} \nValeur : {2} \nCaract\u00e8re non hexad\u00e9cimal : {3} " }, {
        EventMessages.LOG_INVALID_SITUATION_TYPE_EXC_, "IWAT0199E La valeur de la propri\u00e9t\u00e9 sp\u00e9cifi\u00e9e n''est pas valide.\nPropri\u00e9t\u00e9 : {0} \nValeur : {1} \nValeurs admises : {2} " }, {
        EventMessages.LOG_INVALID_CREATION_TIME_EXC_, "IWAT0200E La valeur dateTime de la propri\u00e9t\u00e9 sp\u00e9cifi\u00e9e n''a pas pu \u00eatre interpr\u00e9t\u00e9e.\nPropri\u00e9t\u00e9 : {0} \nValeur : {1} " }, {
        EventMessages.LOG_INVALID_LIST_ELEMENT_LENGTH_EXC_, "IWAT0201E La longueur d''un \u00e9l\u00e9ment dans la propri\u00e9t\u00e9 sp\u00e9cifi\u00e9e d\u00e9passe le nombre maximum de caract\u00e8res.\nPropri\u00e9t\u00e9 : {1} \nEl\u00e9ment : {0} \nLongueur maximale : {2} " }, {
        EventMessages.LOG_VALUE_OUT_OF_RANGE_EXC_, "IWAT0202E La valeur d''une propri\u00e9t\u00e9 est en dehors de la plage valide.\nPropri\u00e9t\u00e9 : {1} \nValeur : {0} \nPlage valide : {2} \u00e0 {3} " }, {
        EventMessages.LOG_MISSING_REQUIRED_ATTRIBUTE_EXC_, "IWAT0203E Il manque une propri\u00e9t\u00e9 obligatoire dans un \u00e9v\u00e9nement Common Base Event.\nPropri\u00e9t\u00e9 : {0} " }, {
        EventMessages.LOG_MUTUALLY_EXCLUSIVE_ATTRIBUTES_EXC_, "IWAT0204E L''\u00e9v\u00e9nement Common Base Event contient des propri\u00e9t\u00e9s qui s''excluent mutuellement.\nPropri\u00e9t\u00e9 1 : {0} \nPropri\u00e9t\u00e9 2 : {1} " }, {
        EventMessages.LOG_INVALID_VERSION_EXC_, "IWAT0205E La version sp\u00e9cifi\u00e9e dans la propri\u00e9t\u00e9 {0} n''est pas valide. La valeur doit \u00eatre 1.0.1.\nValeur : {1} " }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_LENGTH_EXC_, "IWAT0206E La longueur de l''identificateur, dans la propri\u00e9t\u00e9 sp\u00e9cifi\u00e9e de l''\u00e9v\u00e9nement Common Base Event, est en dehors de la plage valide, qui est de 32 \u00e0 64 caract\u00e8res.\nPropri\u00e9t\u00e9 : {0} \nValeur : {1} " }, {
        EventMessages.LOG_INVALID_LENGTH_EXC_, "IWAT0207E La longueur de la valeur, dans la propri\u00e9t\u00e9 sp\u00e9cifi\u00e9e de l''\u00e9v\u00e9nement Common Base Event, d\u00e9passe le nombre maximum de caract\u00e8res.\nPropri\u00e9t\u00e9 : {0} \nValeur : {1} \nLongueur : {2} \nNombre maximal de caract\u00e8res : {3} " }, {
        EventMessages.LOG_INVALID_LENGTH_RANGE_EXC_, "IWAT0208E La longueur de la valeur, dans la propri\u00e9t\u00e9 sp\u00e9cifi\u00e9e de l''\u00e9v\u00e9nement Common Base Event, est en dehors de la plage valide.\nPropri\u00e9t\u00e9 : {0} \nValeur : {1} \nLongueur : {2} \nPlage de longueur valide : {3} " }, {
        EventMessages.LOG_MISSING_ATTRIBUTES_EXC_, "IWAT0209E Les propri\u00e9t\u00e9s sp\u00e9cifi\u00e9es doivent \u00eatre soit toutes pr\u00e9sentes, soit toutes absentes.\nPropri\u00e9t\u00e9s : {0} " }, {
        EventMessages.LOG_INCONSISTENT_ATTRIBUTES_EXC_, "IWAT0210E Lorsque la valeur de la propri\u00e9t\u00e9 {0} figurant dans l''\u00e9v\u00e9nement Common Base Event est \u00e9gale \u00e0 {1}, la liste sp\u00e9cifi\u00e9e de propri\u00e9t\u00e9s ne doit pas \u00eatre pr\u00e9sente.\nListe : {2} " }, {
        EventMessages.LOG_CATEGORY_MISMATCH_EXC_, "IWAT0211E La valeur de la propri\u00e9t\u00e9 {0} ne correspond pas \u00e0 la classe d''objet r\u00e9f\u00e9renc\u00e9e par la propri\u00e9t\u00e9 situationType.\nValeur : {1} \nClasse d''objet : {2}." }, {
        EventMessages.LOG_COMPONENT_IDENTIFICATION_INVALID_LOCATION_TYPE_EXC_, "IWAT0212E L''identification de composant contenant le composant nomm\u00e9 [{0}] comporte un type d''emplacement non valide : [{1}]" }, {
	    EventMessages.LOG_EVENT_SAX_PARSER_UNEXPECTED_XML_ELEMENT_EXC_, "Unexpected element ''{0}'' at line {1}, column {2}." }, {
		EventMessages.LOG_EVENT_SAX_PARSER_INCORRECT_XML_ELEMENT_EXC_ , "Expected element ''{0}'' , but found element ''{1}'' at line {2}, column {3}."}, {
		EventMessages.LOG_EVENT_SAX_PARSER_INVALID_XML_ATTRIBUTE_EXC_ , "IWAT0157E The ''{0}'' attribute contains the invalid value ''{1}'' at line {2}, column {3}."}
    };
}
